import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { is, fromJS } from 'immutable'
import { Icon, Modal } from 'antd'

import zhCN from '@/locales/zh-CN/model.js'
import enUS from '@/locales/en-US/model.js'
import asyncComponent from '@/utils/asyncComponent'
import './index.scss'

const CodeMirror = asyncComponent(() => import('@/templates/zshare/codemirror'))

class DataSource extends Component {
  static propTpyes = {
    config: PropTypes.any,
    updateConfig: PropTypes.func
  }

  state = {
    dict: localStorage.getItem('lang') !== 'en-US' ? zhCN : enUS,
    visible: false,
    html: null
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.props), fromJS(nextProps)) || !is(fromJS(this.state), fromJS(nextState))
  }

  trigger = () => {
    const { config } = this.props

    this.setState({
      visible: true,
      html: config.html || null
    })
  }

  verifySubmit = () => {
    const { config } = this.props
    const { html } = this.state

    this.setState({
      visible: false
    })
    this.props.updateConfig({...config, html})
  }

  onChange = (val) => {
    this.setState({
      html: val
    })
  }

  render () {
    const { config } = this.props
    const { visible, dict, html } = this.state

    if (!config) return null

    return (
      <div className="model-menu-edit-content-wrap">
        {config.wrap.datatype === 'static' ? <Icon title="内容编辑" type="form" onClick={() => this.trigger()} /> : null}
        {config.wrap.datatype !== 'static' ? <Icon title="内容编辑" style={{color: '#eeeeee', cursor: 'not-allowed'}} type="form"/> : null}
        <Modal
          wrapClassName="popview-modal model-menu-edit-content-form"
          title="内容编辑"
          visible={visible}
          width={950}
          maskClosable={false}
          okText={dict['model.submit']}
          onOk={this.verifySubmit}
          onCancel={() => { this.setState({ visible: false }) }}
          destroyOnClose
        >
          <CodeMirror value={html} onChange={this.onChange} />
        </Modal>
      </div>
    )
  }
}

export default DataSource